==> robocasa-0.2.0a3-py3-none-any.whl: robocasa/scripts/upload_func.py <==
      
from datetime import datetime
from termcolor import colored
import requests, os, json

# 服务器基础URL配置
BASE_URL = "http://assetserver.lightwheel.net"
# HTTP请求头配置
HEADERS = {
    "Content-Type": "application/json",
}
# 时间格式常量
TIME_FORMAT = "%Y-%m-%dT%H:%M:%SZ"

# 用于存储测试用例中的版本UUID
# 所有的操作均基于VerionUUID进行
# 目前可能一个遥操作只有一个版本，这样设计是为了后续接入项目管理等功能

VERSION_UUID = ""
TELEOPERATION_UUID = ""


def post(action, json, service="asset", table="teleoperation"):
    """
    通用POST请求处理函数

    Args:
        action (str): API动作名称
        json (dict): 请求体数据
        service (str): 服务名称，默认为"asset", 登陆认证服务为"authenticate"
        table (str): 表名称，默认为"teleoperation"

    Returns:
        dict: API响应数据

    Raises:
        Exception: 当请求失败时抛出异常
    """
    url = f"{BASE_URL}/api/{service}/v1/{table}/{action}"
    res = requests.post(url, headers=HEADERS, json=json)
    if res.status_code != 200:
        print(res.text)
        raise Exception(f"Failed to post request to {service} {table} {action}")
    res = res.json()
    return res


def login(user_name, password):
    """
    测试用户登录接口
    - 使用测试账号登录系统
    - 获取认证token并更新全局请求头

    Returns:
        dict: 登录响应数据，包含token等信息
    """
    login_payload = {"username": user_name, "password": password}
    global HEADERS
    res = post("login", login_payload, "authenticate", "user")
    # print(res)
    HEADERS["Authorization"] = f"Bearer {res['token']}"
    HEADERS["UserName"] = user_name
    return res


def upload(test_files: dict[str, str], teleoperation_uuid: str = "", version_uuid: str = ""):
    """
    测试文件上传接口

    Args:
        test_files (dict[str, str]): 待上传文件信息，格式为 {key: (文件名, 文件路径)}
        teleoperation_uuid (str): 遥操作UUID, AddVideo时需要，Create时不需要填后端自动生成
        version_uuid (str): 版本UUID，AddVideo时需要，Create时不需要填后端自动生成

    Returns:
        dict: 上传文件的响应信息，包含文件路径等数据
    """
    headers = HEADERS.copy()
    headers.pop("Content-Type", None)  # 移除Content-Type头，因为是文件上传
    data = {
        "uuid": teleoperation_uuid,
        "version": version_uuid,
        "keep_same_version": "true",
    }

    # 准备上传文件
    files = {}
    for key, (file_name, file_path) in test_files.items():
        files[key] = (file_name, open(file_path, "rb"))

    res = requests.post(f"{BASE_URL}/upload", files=files, headers=headers, data=data)
    res = res.json()
    info = res["UploadedInfos"]
    return info


def get():
    """
    测试获取遥操作列表接口
    - 获取所有遥操作记录
    - 保存第一条记录的UUID信息用于后续测试
    """
    payload = {
        "search_request": {},
    }
    res = post("get", payload)
    global TELEOPERATION_UUID
    global VERSION_UUID
    print(len(res["data"]))
    for r in res["data"]:
        print(r)
        VERSION_UUID = r["versionUuid"]
        TELEOPERATION_UUID = r["teleoperationUuid"]
        break


def create(name: str, robot_name: str, layout_id: str, file_path: str, video_path: str):
    """
    测试创建新的遥操作记录
    - 上传测试用的tar文件
    - 创建新的遥操作记录，包含文件信息
    - 创建时必须要有files，即想要上传的压缩包文件
    - 创建时可选是否上传视频，如果不上传后续可通过AddVideo接口添加
    """

    # print(HEADERS)
    file_key = "file"
    video_key = "video"
    # 上传文件, 上传文件通过后端通用上传接口进行，返回文件UUID，版本UUID，上传路径
    if video_path == "" :
        info = upload({file_key: (f"{name}.tar", file_path)})
    else: info = upload({file_key: (f"{name}.tar", file_path), video_key: (f"{name}.mp4", video_path)})
    # 支持批量上传，每个文件需要有自己的key，在接口返回信息中通过该key获取上传信息
    file = info[file_key]
    if video_path != "":
        video = info[video_key]
    # print(file)

    # 创建遥操作记录，version_uuid和teleoperation_uuid必须
    teles = [
        {
            "version_uuid": file["Version"],
            "teleoperation_uuid": file["UUID"],
            "name": f"teleoperation_{datetime.now().strftime('%Y%m%d%H%M%S')}",
            "description": f"{name.split('-')[0]}-{robot_name}-{layout_id}",
            "files": [
                {"name": f"{name}.tar", "path": file["UploadPath"]},
            ],
        }
    ]
    if video_path != "":
        teles[0]["video"] = {"name": f"{name}.mp4", "path": video["UploadPath"]}

    payload = {
        "teleoperations": teles,
    }

    post("create", payload)


def add_video():
    """
    测试为现有遥操作添加新视频
    - 上传新的测试视频文件
    - 将视频关联到之前获取的遥操作记录
    """
    video_key = "video"
    info = upload(
        {
            video_key: ("newTest.mp4", "asset/newTest.mp4"),
        },
        TELEOPERATION_UUID,
        VERSION_UUID,
    )
    _video = info[video_key]
    video = {
        "name": "newTest.mp4",
        "path": _video["UploadPath"],
    }
    video_info = {
        "version_uuid": VERSION_UUID,
        "video": video,
    }

    payload = {
        "videos": [video_info],
    }
    post("add_video", payload)


if __name__ == "__main__":
    """
    主函数：按顺序执行完整的测试流程
    1. 登录系统获取认证，所有请求都要带上带有登陆认证信息的请求头
    2. 创建新的遥操作记录
    3. 获取遥操作列表
    4. 为遥操作添加新视频
    """
    login()
    create()
    get()
    add_video()

==> robocasa-0.2.1-py3-none-any.whl: robocasa/scripts/upload_func.py <==
      
from datetime import datetime
from termcolor import colored
import requests, os, json

# 服务器基础URL配置
BASE_URL = "http://assetserver.lightwheel.net"
# HTTP请求头配置
HEADERS = {
    "Content-Type": "application/json",
}
# 时间格式常量
TIME_FORMAT = "%Y-%m-%dT%H:%M:%SZ"

# 用于存储测试用例中的版本UUID
# 所有的操作均基于VerionUUID进行
# 目前可能一个遥操作只有一个版本，这样设计是为了后续接入项目管理等功能

VERSION_UUID = ""
TELEOPERATION_UUID = ""


def post(action, json, service="asset", table="teleoperation"):
    """
    通用POST请求处理函数

    Args:
        action (str): API动作名称
        json (dict): 请求体数据
        service (str): 服务名称，默认为"asset", 登陆认证服务为"authenticate"
        table (str): 表名称，默认为"teleoperation"

    Returns:
        dict: API响应数据

    Raises:
        Exception: 当请求失败时抛出异常
    """
    url = f"{BASE_URL}/api/{service}/v1/{table}/{action}"
    res = requests.post(url, headers=HEADERS, json=json)
    if res.status_code != 200:
        print(res.text)
        raise Exception(f"Failed to post request to {service} {table} {action}")
    res = res.json()
    return res


def login(user_name, password):
    """
    测试用户登录接口
    - 使用测试账号登录系统
    - 获取认证token并更新全局请求头

    Returns:
        dict: 登录响应数据，包含token等信息
    """
    login_payload = {"username": user_name, "password": password}
    global HEADERS
    res = post("login", login_payload, "authenticate", "user")
    # print(res)
    HEADERS["Authorization"] = f"Bearer {res['token']}"
    HEADERS["UserName"] = user_name
    return res


def upload(test_files: dict[str, str], teleoperation_uuid: str = "", version_uuid: str = ""):
    """
    测试文件上传接口

    Args:
        test_files (dict[str, str]): 待上传文件信息，格式为 {key: (文件名, 文件路径)}
        teleoperation_uuid (str): 遥操作UUID, AddVideo时需要，Create时不需要填后端自动生成
        version_uuid (str): 版本UUID，AddVideo时需要，Create时不需要填后端自动生成

    Returns:
        dict: 上传文件的响应信息，包含文件路径等数据
    """
    headers = HEADERS.copy()
    headers.pop("Content-Type", None)  # 移除Content-Type头，因为是文件上传
    data = {
        "uuid": teleoperation_uuid,
        "version": version_uuid,
        "keep_same_version": "true",
    }

    # 准备上传文件
    files = {}
    for key, (file_name, file_path) in test_files.items():
        files[key] = (file_name, open(file_path, "rb"))

    res = requests.post(f"{BASE_URL}/upload", files=files, headers=headers, data=data)
    res = res.json()
    info = res["UploadedInfos"]
    return info


def get():
    """
    测试获取遥操作列表接口
    - 获取所有遥操作记录
    - 保存第一条记录的UUID信息用于后续测试
    """
    payload = {
        "search_request": {},
    }
    res = post("get", payload)
    global TELEOPERATION_UUID
    global VERSION_UUID
    print(len(res["data"]))
    for r in res["data"]:
        print(r)
        VERSION_UUID = r["versionUuid"]
        TELEOPERATION_UUID = r["teleoperationUuid"]
        break


def create(name: str, file_path: str, video_path: str):
    """
    测试创建新的遥操作记录
    - 上传测试用的tar文件
    - 创建新的遥操作记录，包含文件信息
    - 创建时必须要有files，即想要上传的压缩包文件
    - 创建时可选是否上传视频，如果不上传后续可通过AddVideo接口添加
    """

    # print(HEADERS)
    file_key = "file"
    video_key = "video"
    # 上传文件, 上传文件通过后端通用上传接口进行，返回文件UUID，版本UUID，上传路径
    if video_path == "" :
        info = upload({file_key: (f"{name}.tar", file_path)})
    else: info = upload({file_key: (f"{name}.tar", file_path), video_key: (f"{name}.mp4", video_path)})
    # 支持批量上传，每个文件需要有自己的key，在接口返回信息中通过该key获取上传信息
    file = info[file_key]
    if video_path != "":
        video = info[video_key]
    # print(file)

    # 创建遥操作记录，version_uuid和teleoperation_uuid必须
    teles = [
        {
            "version_uuid": file["Version"],
            "teleoperation_uuid": file["UUID"],
            "name": f"teleoperation_{datetime.now().strftime('%Y%m%d%H%M%S')}",
            "description": f"{name.split('-')[0]}",
            "files": [
                {"name": f"{name}.tar", "path": file["UploadPath"]},
            ],
        }
    ]
    if video_path != "":
        teles[0]["video"] = {"name": f"{name}.mp4", "path": video["UploadPath"]}

    payload = {
        "teleoperations": teles,
    }

    post("create", payload)


def add_video():
    """
    测试为现有遥操作添加新视频
    - 上传新的测试视频文件
    - 将视频关联到之前获取的遥操作记录
    """
    video_key = "video"
    info = upload(
        {
            video_key: ("newTest.mp4", "asset/newTest.mp4"),
        },
        TELEOPERATION_UUID,
        VERSION_UUID,
    )
    _video = info[video_key]
    video = {
        "name": "newTest.mp4",
        "path": _video["UploadPath"],
    }
    video_info = {
        "version_uuid": VERSION_UUID,
        "video": video,
    }

    payload = {
        "videos": [video_info],
    }
    post("add_video", payload)


if __name__ == "__main__":
    """
    主函数：按顺序执行完整的测试流程
    1. 登录系统获取认证，所有请求都要带上带有登陆认证信息的请求头
    2. 创建新的遥操作记录
    3. 获取遥操作列表
    4. 为遥操作添加新视频
    """
    login()
    create()
    get()
    add_video()
